pub fn select_memory(raw: &str) -> Result<SelectedMemory, SelectionRefusal>Expand description
The selection a written value names, refusing everything that must not become one. Nothing is written and no store is opened.
pub fn select_memory(raw: &str) -> Result<SelectedMemory, SelectionRefusal>The selection a written value names, refusing everything that must not become one. Nothing is written and no store is opened.